@@ -17,10 +17,11 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with damewebutils; see the file LICENSE.  If not, write to
+# along with dameweblibraries; see the file LICENSE.  If not, write to
 # the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301 USA,
 
+
 import socket
 import sys
 
@@ -28,17 +29,13 @@ HOST, PORT = "localhost", 9999
 data = " ".join(sys.argv[1:])
 
 # Create a socket (SOCK_STREAM means a TCP socket)
-sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
+        # Connect to server and send data
+        sock.connect((HOST, PORT))
+        sock.sendall(bytes(data + "\n", "utf-8"))
 
-try:
-    # Connect to server and send data
-    sock.connect((HOST, PORT))
-    sock.sendall(data + "\n")
+        # Receive data from the server and shut down
+        received = str(sock.recv(1024), "utf-8")
 
-    # Receive data from the server and shut down
-    received = sock.recv(1024)
-finally:
-    sock.close()
-
-print "Sent:     {}".format(data)
-print "Received: {}".format(received)
+print("Sent:     {}".format(data))
+print("Received: {}".format(received))
